@@ -289,7 +289,7 @@ class Index(BaseModel):
         while self.state not in [IndexBuildState.failed, IndexBuildState.complete]:
             print(f"Index Status: {self.build_status}")  # XXX provide percentage completion
             data = {'tag': self.tag}
-            resp = session.get (f"/collections/{self.collection.id}/index?{urllib.parse.urlencode(data)}")
+            resp = session.get(f"/collections/{self.collection.id}/index?{urllib.parse.urlencode(data)}")
             items = resp.json()['items'][0]
             self.__dict__.update(items)
             sleep(2)  # XXX update sleep time based on something like halfway toward the estimated remaining completed_at estimate
@@ -313,7 +313,28 @@ class Index(BaseModel):
         ix.set_ef(ef)
         return ix
 
+    def tests(self):
+        """
+        Return the IndexTest results for this index
+        """
+        tests = session.get(f'/collections/{self.collection.id}/index/{self.id}/tests').json()['items']
+        return [IndexTest(**test, index=self) for test in tests]
 
+
+class IndexTest(BaseModel):
+    id:                   int = Field(description="Unique database identifier for a given index test.")
+    index:              Index = Field(description="The index under test.")
+    test_count:           int = Field(description="The number of vectors in the test sample.")
+    test_k:               int = Field(description="The number of nearest neighbors (k) to query for each test vector.")
+    recall:             float = Field(description="The recall of the index based on a comparison to exhaustive KNN.")
+    qps:                float = Field(description="The estimated queries per second of the index for vector search with batchsize of 1 (a single vector at a time).")
+    cpu_info:             str = Field(description="The CPU that executed the test.")
+    created_at:         float = Field(description="The epoch timestamp when the test was completed.")
+    hnswlib_ef: Optional[int] = Field(default=None, description="The ef value passed to hnsw_index.set_ef() for this test.")
+        
+    def __repr__(self):
+        return f"{self.index.name:20s}: recall: {self.recall:5.3f}  QPS: {self.qps:7.1f} @ EF={self.hnswlib_ef}"
+    
 ###
 ##  Teams
 ###
